@@ -1,8 +1,8 @@
 from __future__ import print_function
 
-import unittest
-import sys
 import os
+import sys
+import unittest
 
 __mydir = os.path.dirname(sys.argv[0])
 if not os.path.isdir(__mydir):
@@ -33,10 +33,22 @@ def recurmatch(aug, path):
                     yield x
 
 class TestAugeas(unittest.TestCase):
-    def test01Get(self):
-        "test aug_get"
+    def test01aGetNone(self):
+        "test aug_get with non-existing path"
         a = augeas.Augeas(root=MYROOT)
-        self.failUnless(a.get("/wrong/path") == None)
+        self.failUnless(a.get("/wrong/path") is None)
+        del a
+
+    def test01bGetValue(self):
+        "test aug_get with existing path"
+        a = augeas.Augeas(root=MYROOT)
+        self.assertEqual(a.get("/files/etc/hosts/1/ipaddr"), "127.0.0.1")
+        del a
+
+    def test01cGetException(self):
+        "test aug_get with incorrect path"
+        a = augeas.Augeas(root=MYROOT)
+        self.assertRaises(ValueError, a.get, "/files//[1]/")
         del a
 
     def test02Match(self):
@@ -86,7 +98,7 @@ class TestAugeas(unittest.TestCase):
             for attr in a.match(i+"/*"):
                 self.failUnless(a.get(attr) != None)
         del a
-        
+
     def test06Defnode(self):
         "test defnode"
         a = augeas.Augeas(root=MYROOT)
@@ -158,6 +170,10 @@ class TestAugeas(unittest.TestCase):
             error = e
         self.assertTrue(isinstance(error, ValueError))
 
+    def testSetNone(self):
+        a = augeas.Augeas(root=MYROOT)
+        r = a.set("/raw/hosts", None);
+
     def test10TextRetrieve(self):
         hosts = "192.168.0.1 rtr.example.com router\n"
         a = augeas.Augeas(root=MYROOT)
@@ -212,12 +228,42 @@ class TestAugeas(unittest.TestCase):
         excl = a.get("/augeas/load/Foo/excl")
         self.assertEqual(excl, "/tmp/baz")
 
-    def test14Label(self):
+    def test14aLabelOk(self):
+        """test aug_label with valid input"""
         a = augeas.Augeas(root=MYROOT)
 
         lbl = a.label("/augeas/version")
         self.assertEqual(lbl, "version")
 
+    def test14bLabelException(self):
+        """test aug_label with invalid input"""
+        a = augeas.Augeas(root=MYROOT)
+
+        self.assertRaises(ValueError, a.label, "/augeas/version/[1]/")
+
+    def test15Copy(self):
+        a = augeas.Augeas(root=MYROOT)
+
+        orig_path = '/tmp/src/copy_test/a'
+        copy_path = '/tmp/dst/copy_test/a'
+        orig_value = 'test value'
+
+        a.set(orig_path, orig_value)
+
+        matches = a.match(orig_path)
+        self.failUnless(matches)
+
+        a.copy(orig_path, copy_path)
+
+        matches = a.match(copy_path)
+        self.failUnless(matches)
+        self.assertEqual(a.get(copy_path), a.get(orig_path))
+
+    def testClose(self):
+        a = augeas.Augeas(root=MYROOT)
+        a.close()
+
+
 def getsuite():
     suite = unittest.TestSuite()
     suite = unittest.makeSuite(TestAugeas, 'test')
